Struct lldb::LaunchFlags [] [src]

#[repr(C)]
pub struct LaunchFlags { /* fields omitted */ }

Methods

impl LaunchFlags
[src]

EXEC: LaunchFlags = LaunchFlags{bits: 1,}

Exec when launching and turn the calling process into a new process.

DEBUG: LaunchFlags = LaunchFlags{bits: 2,}

Stop as soon as the process launches to allow the process to be debugged.

STOP_AT_ENTRY: LaunchFlags = LaunchFlags{bits: 4,}

Stop at the program entry point instead of auto-continuing when launching or attaching at entry point.

DISABLE_ASLR: LaunchFlags = LaunchFlags{bits: 8,}

Disable address space layout randomization (ASLR).

DISABLE_STDIO: LaunchFlags = LaunchFlags{bits: 16,}

Disable stdio for the inferior process (e.g. for a GUI app).

LAUNCH_IN_TTY: LaunchFlags = LaunchFlags{bits: 32,}

Launch the process in a new TTY if supported by the host.

LAUNCH_IN_SHELL: LaunchFlags = LaunchFlags{bits: 64,}

Launch the process inside a shell to get shell expansion.

LAUNCH_IN_SEPARATE_PROCESS_GROUP: LaunchFlags = LaunchFlags{bits: 128,}

Launch the process in a separate process group.

DONT_SET_EXIT_STATUS: LaunchFlags = LaunchFlags{bits: 256,}

If you are going to hand the process off (e.g. to debugserver), set this flag so that lldb and the handee don't race to set its exit status.

DETACH_ON_ERRROR: LaunchFlags = LaunchFlags{bits: 512,}

If set, then the client stub should detach rather than killing the debugee.

SHELL_EXPAND_ARGUMENTS: LaunchFlags = LaunchFlags{bits: 1024,}

Perform shell-style argument expansion.

CLOSE_TTY_ON_EXIT: LaunchFlags = LaunchFlags{bits: 2048,}

Close the open TTY on exit.

[src]

Returns an empty set of flags.

[src]

Returns the set containing all flags.

[src]

Returns the raw value of the flags currently stored.

[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

[src]

Returns true if no flags are currently stored.

[src]

Returns true if all flags are currently set.

[src]

Returns true if there are flags common to both self and other.

[src]

Returns true all of the flags in other are contained within self.

[src]

Inserts the specified flags in-place.

[src]

Removes the specified flags in-place.

[src]

Toggles the specified flags in-place.

[src]

Inserts or removes the specified flags depending on the passed value.