Struct lldb::SBBlock
[−]
[src]
pub struct SBBlock {
pub raw: SBBlockRef,
}A lexical block.
Fields
raw: SBBlockRef
The underlying raw SBBlockRef.
Methods
impl SBBlock[src]
pub fn wrap(raw: SBBlockRef) -> SBBlock[src]
Construct a new SBBlock.
pub fn maybe_wrap(raw: SBBlockRef) -> Option<SBBlock>[src]
Construct a new Some(SBBlock) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBBlock value.
pub fn is_inlined(&self) -> bool[src]
Does this block represent an inlined function?
pub fn inlined_name(&self) -> &str[src]
Get the function name if this block represents an inlined function.
pub fn inlined_call_site_file(&self) -> Option<SBFileSpec>[src]
Get the call site file if this block represents an inlined function.
pub fn inlined_call_site_line(&self) -> Option<u32>[src]
Get the call site line number if this block represents an inlined function.
pub fn inlined_call_site_column(&self) -> Option<u32>[src]
Get the call site column number if this block represents an inlined function.
pub fn parent(&self) -> Option<SBBlock>[src]
Get the parent block
pub fn containing_inlined_block(&self) -> Option<SBBlock>[src]
Get the inlined block that is or contains this block.
pub fn sibling(&self) -> Option<SBBlock>[src]
Get the sibling block for this block.
pub fn first_child(&self) -> Option<SBBlock>[src]
Get the first child block for this block.
pub fn num_ranges(&self) -> u32[src]
The number of address ranges associated with this block.
pub fn range_start_address(&self, idx: u32) -> SBAddress[src]
Get the start address of an address range.
pub fn range_end_address(&self, idx: u32) -> SBAddress[src]
Get the end address of an address range.
pub fn range_index_for_block_address(&self, block_address: &SBAddress) -> u32[src]
Given an address, find out which address range it is part of.