Struct lldb::SBBreakpointLocation
[−]
[src]
pub struct SBBreakpointLocation {
pub raw: SBBreakpointLocationRef,
}One unique instance (by address) of a logical breakpoint.
A breakpoint location is defined by the breakpoint that produces it, and the address that resulted in this particular instantiation. Each breakpoint location has its settable options.
SBBreakpoint contains SBBreakpointLocation(s).
See SBBreakpoint for retrieval of an SBBreakpointLocation
from an SBBreakpoint.
Fields
raw: SBBreakpointLocationRef
The underlying raw SBBreakpointLocationRef.
Methods
impl SBBreakpointLocation[src]
pub fn wrap(raw: SBBreakpointLocationRef) -> SBBreakpointLocation[src]
Construct a new SBBreakpointLocation.
pub fn maybe_wrap(raw: SBBreakpointLocationRef) -> Option<SBBreakpointLocation>[src]
Construct a new Some(SBBreakpointLocation) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBBreakpointLocation value.
pub fn id(&self) -> i32[src]
pub fn address(&self) -> Option<SBAddress>[src]
pub fn load_address(&self) -> lldb_addr_t[src]
pub fn is_enabled(&self) -> bool[src]
pub fn set_enabled(&self, enabled: bool)[src]
pub fn ignore_count(&self) -> u32[src]
pub fn set_ignore_count(&self, count: u32)[src]
pub fn is_resolved(&self) -> bool[src]
pub fn breakpoint(&self) -> SBBreakpoint[src]