Struct lldb::SBError
[−]
[src]
pub struct SBError {
pub raw: SBErrorRef,
}A container for holding any error code.
Fields
raw: SBErrorRef
The underlying raw SBErrorRef.
Methods
impl SBError[src]
pub fn new() -> SBError[src]
Construct a new SBError.
pub fn wrap(raw: SBErrorRef) -> SBError[src]
Construct a new SBError.
pub fn maybe_wrap(raw: SBErrorRef) -> Option<SBError>[src]
Construct a new Some(SBError) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBError value.
pub fn error_string(&self) -> &str[src]
Any textual error message associated with the error.
pub fn is_failure(&self) -> bool[src]
Does this error represent a failure?
pub fn is_success(&self) -> bool[src]
Does this error represent a success?
pub fn error(&self) -> u32[src]
The underlying error code. Must be interpreted in conjunction with the error type.
pub fn error_type(&self) -> ErrorType[src]
What type of error is this?