Struct lldb::SBFileSpec
[−]
[src]
pub struct SBFileSpec {
pub raw: SBFileSpecRef,
}A file specification that divides the path into a directory and basename.
The string values of the paths are put into uniqued string pools for fast comparisons and efficient memory usage.
Fields
raw: SBFileSpecRef
The underlying raw SBFileSpecRef.
Methods
impl SBFileSpec[src]
pub fn wrap(raw: SBFileSpecRef) -> SBFileSpec[src]
Construct a new SBFileSpec.
pub fn maybe_wrap(raw: SBFileSpecRef) -> Option<SBFileSpec>[src]
Construct a new Some(SBFileSpec) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBFileSpec value.
pub fn exists(&self) -> bool[src]
Does this file exist?
pub fn filename(&self) -> &str[src]
The path file name.
pub fn directory(&self) -> &str[src]
The path directory name.