Struct lldb::SBFunction
[−]
[src]
pub struct SBFunction {
pub raw: SBFunctionRef,
}A generic function, which can be inlined or not.
Fields
raw: SBFunctionRef
The underlying raw SBFunctionRef.
Methods
impl SBFunction[src]
pub fn wrap(raw: SBFunctionRef) -> SBFunction[src]
Construct a new SBFunction.
pub fn maybe_wrap(raw: SBFunctionRef) -> Option<SBFunction>[src]
Construct a new Some(SBFunction) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBFunction value.
pub fn name(&self) -> &str[src]
The name of this function.
pub fn display_name(&self) -> &str[src]
The display name for the function, as it should be seen in a UI.
pub fn mangled_name(&self) -> &str[src]
The mangled (linkage) name for this function.
pub fn get_instructions(
&self,
target: &SBTarget,
flavor: DisassemblyFlavor
) -> SBInstructionList[src]
&self,
target: &SBTarget,
flavor: DisassemblyFlavor
) -> SBInstructionList
pub fn start_address(&self) -> SBAddress[src]
Get the address of the start of this function.
pub fn end_address(&self) -> SBAddress[src]
Get the address of the end of this function.
pub fn prologue_byte_size(&self) -> u32[src]
Get the size of the function prologue, in bytes.
pub fn return_type(&self) -> SBType[src]
The return type for this function.
pub fn block(&self) -> SBBlock[src]
Get the top level lexical block for this function.
pub fn language(&self) -> LanguageType[src]
The language that this function was written in.
pub fn is_optimized(&self) -> bool[src]
Returns true if the function was compiled with optimization.
Optimization, in this case, is meant to indicate that the debugger experience may be confusing for the user -- variables optimized away, stepping jumping between source lines -- and the driver may want to provide some guidance to the user about this. Returns false if unoptimized, or unknown.