Struct lldb::SBInstruction
[−]
[src]
pub struct SBInstruction {
pub raw: SBInstructionRef,
}A machine instruction.
Fields
raw: SBInstructionRef
The underlying raw SBInstructionRef.
Methods
impl SBInstruction[src]
pub fn wrap(raw: SBInstructionRef) -> SBInstruction[src]
Construct a new SBInstruction.
pub fn maybe_wrap(raw: SBInstructionRef) -> Option<SBInstruction>[src]
Construct a new Some(SBInstruction) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBInstruction value.
pub fn address(&self) -> SBAddress[src]
Get the address of the instruction.
pub fn address_class(&self) -> AddressClass[src]
Get the address class for the address of the instruction.
pub fn mnemonic(&self, target: &SBTarget) -> &str[src]
pub fn operands(&self, target: &SBTarget) -> &str[src]
pub fn comment(&self, target: &SBTarget) -> &str[src]
pub fn data(&self, target: &SBTarget) -> SBData[src]
pub fn byte_size(&self) -> u32[src]
pub fn is_branch(&self) -> bool[src]
pub fn has_delay_slot(&self) -> bool[src]