Struct lldb::SBLineEntry
[−]
[src]
pub struct SBLineEntry {
pub raw: SBLineEntryRef,
}Specifies an association with a contiguous range of instructions and a source file location.
Fields
raw: SBLineEntryRef
The underlying raw SBLineEntryRef.
Methods
impl SBLineEntry[src]
pub fn wrap(raw: SBLineEntryRef) -> SBLineEntry[src]
Construct a new SBLineEntry.
pub fn maybe_wrap(raw: SBLineEntryRef) -> Option<SBLineEntry>[src]
Construct a new Some(SBLineEntry) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBLineEntry value.
pub fn start_address(&self) -> SBAddress[src]
The start address for this line entry.
pub fn end_address(&self) -> SBAddress[src]
The end address for this line entry.
pub fn filespec(&self) -> SBFileSpec[src]
The file (SBFileSpec) for this line entry.
pub fn line(&self) -> u32[src]
The 1-based line number for this line entry.
A return value of 0 indicates that no line information is
available.
pub fn column(&self) -> u32[src]
The 1-based column number for this line entry.
A return value of 0 indicates that no column information is
available.