Struct lldb::SBModule
[−]
[src]
pub struct SBModule {
pub raw: SBModuleRef,
}An executable image and its associated object and symbol files.
Fields
raw: SBModuleRef
The underlying raw SBModuleRef.
Methods
impl SBModule[src]
pub fn wrap(raw: SBModuleRef) -> SBModule[src]
Construct a new SBModule.
pub fn maybe_wrap(raw: SBModuleRef) -> Option<SBModule>[src]
Construct a new Some(SBModule) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBModule value.
pub fn filespec(&self) -> SBFileSpec[src]
The file for the module on the host system that is running LLDB.
This can differ from the path on the platform since we might be doing remote debugging.
pub fn platform_filespec(&self) -> SBFileSpec[src]
The file for the module as it is known on the remote system on which it is being debugged.
For local debugging this is always the same as SBModule::filespec.
But remote debugging might mention a file /usr/lib/liba.dylib
which might be locally downloaded and cached. In this case the
platform file could be something like:
/tmp/lldb/platform-cache/remote.host.computer/usr/lib/liba.dylib
The file could also be cached in a local developer kit directory.
pub fn find_section(&self, name: &str) -> Option<SBSection>[src]
ⓘImportant traits for SBModuleSectionIter<'d>pub fn sections(&self) -> SBModuleSectionIter[src]
Get an iterator over the sections known to this module instance.