Struct lldb::SBModuleSpec
[−]
[src]
pub struct SBModuleSpec {
pub raw: SBModuleSpecRef,
}A description of an SBModule.
Fields
raw: SBModuleSpecRef
The underlying raw SBModuleSpecRef.
Methods
impl SBModuleSpec[src]
pub fn wrap(raw: SBModuleSpecRef) -> SBModuleSpec[src]
Construct a new SBModuleSpec.
pub fn maybe_wrap(raw: SBModuleSpecRef) -> Option<SBModuleSpec>[src]
Construct a new Some(SBModuleSpec) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBModuleSpec value.
pub fn filespec(&self) -> SBFileSpec[src]
The file for the module on the host system that is running LLDB.
This can differ from the path on the platform since we might be doing remote debugging.
pub fn set_filespec(&self, filespec: &SBFileSpec)[src]
Set the file for the module on the host system that is running LLDB.
pub fn platform_filespec(&self) -> SBFileSpec[src]
The file for the module as it is known on the remote system which is being debugged.
For local debugging, this is always the same as SBModuleSpec::filespec.
But remote debugging might mention a file /usr/lib/liba.dylib
which might be locally downloaded and cached. In this case, the
platform file could be something like:
/tmp/lldb/platform-cache/remote.host.computer/usr/lib/liba.dylib
The file could also be cached in a local developer kit directory.
pub fn set_platform_filespec(&self, filespec: &SBFileSpec)[src]
Set the file for the module as it is known on the remote system which is being debugged.
pub fn symbol_filespec(&self) -> Option<SBFileSpec>[src]
pub fn set_symbol_filespec(&self, filespec: &SBFileSpec)[src]
pub fn object_name(&self) -> &str[src]
pub fn set_object_name(&self, _object_name: &str)[src]
pub fn triple(&self) -> &str[src]
pub fn set_triple(&self, _object_name: &str)[src]
pub fn uuid_bytes(&self) -> &str[src]
pub fn set_uuid_bytes(&self, _object_name: &str)[src]