Struct lldb::SBPlatform
[−]
[src]
pub struct SBPlatform {
pub raw: SBPlatformRef,
}A platform that can represent the current host or a remote host debug platform.
The SBPlatform class represents the current host, or a remote host.
It can be connected to a remote platform in order to provide ways
to remotely launch and attach to processes, upload/download files,
create directories, run remote shell commands, find locally cached
versions of files from the remote system, and much more.
SBPlatform objects can be created and then used to connect to a remote
platform which allows the SBPlatform to be used to get a list of the
current processes on the remote host, attach to one of those processes,
install programs on the remote system, attach and launch processes,
and much more.
Every SBTarget has a corresponding SBPlatform. The platform can be
specified upon target creation, or the currently selected platform
will attempt to be used when creating the target automatically as long
as the currently selected platform matches the target architecture
and executable type. If the architecture or executable type do not match,
a suitable platform will be found automatically.
Fields
raw: SBPlatformRef
The underlying raw SBPlatformRef.
Methods
impl SBPlatform[src]
pub fn wrap(raw: SBPlatformRef) -> SBPlatform[src]
Construct a new SBPlatform.
pub fn maybe_wrap(raw: SBPlatformRef) -> Option<SBPlatform>[src]
Construct a new Some(SBPlatform) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBPlatform value.
pub fn working_directory(&self) -> &str[src]
The working directory for this platform.
pub fn name(&self) -> &str[src]
The name of the platform.
When debugging on the host platform, this would be "host".
pub fn triple(&self) -> &str[src]
The triple used to describe this platform.
An example value might be "x86_64-apple-macosx".
pub fn hostname(&self) -> &str[src]
The hostname for this platform.
pub fn os_build(&self) -> &str[src]
The build ID for the platforms' OS version.
pub fn os_description(&self) -> &str[src]
The long form description of the platform's OS version.
On Mac OS X, this might look like "Darwin Kernel Version 15.5.0: Tue Apr 19 18:36:36 PDT 2016; root:xnu-3248.50.21~8/RELEASE_X86_64".
pub fn os_major_version(&self) -> u32[src]
The major component of the platform's OS version.
On Mac OS X 10.11.4, this would have the value 10.
pub fn os_minor_version(&self) -> u32[src]
The minor component of the platform's OS version.
On Mac OS X 10.11.4, this would have the value 11.
pub fn os_update_version(&self) -> u32[src]
The patch or update component of the platform's OS version.
On Mac OS X 10.11.4, this would have the value 4.
pub fn launch(&self, launch_info: &SBLaunchInfo) -> Result<(), SBError>[src]
Launch a process. This is not for debugging that process.
pub fn kill(&self, pid: lldb_pid_t) -> Result<(), SBError>[src]
Kill a process.