Struct lldb::SBSection
[−]
[src]
pub struct SBSection {
pub raw: SBSectionRef,
}Fields
raw: SBSectionRef
The underlying raw SBSectionRef.
Methods
impl SBSection[src]
pub fn wrap(raw: SBSectionRef) -> SBSection[src]
Construct a new SBSection.
pub fn maybe_wrap(raw: SBSectionRef) -> Option<SBSection>[src]
Construct a new Some(SBSection) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBSection value.
pub fn name(&self) -> &str[src]
The section name.
pub fn parent(&self) -> Option<SBSection>[src]
The section parent, if there is one.
pub fn find_subsection(&self, name: &str) -> Option<SBSection>[src]
ⓘImportant traits for SBSectionSubSectionIter<'d>pub fn subsections(&self) -> SBSectionSubSectionIter[src]
ⓘImportant traits for SBSectionSubSectionIter<'d>
Get an iterator over the subsections known to this section instance.
pub fn file_address(&self) -> u64[src]
pub fn load_address(&self, target: &SBTarget) -> u64[src]
pub fn byte_size(&self) -> u64[src]
pub fn file_offset(&self) -> u64[src]
pub fn file_byte_size(&self) -> u64[src]
pub fn section_data(&self) -> SBData[src]
pub fn section_data_slice(&self, offset: u64, size: u64) -> SBData[src]
pub fn section_type(&self) -> SectionType[src]
pub fn target_byte_size(&self) -> u32[src]