Struct lldb::SBStream
[−]
[src]
pub struct SBStream {
pub raw: SBStreamRef,
}A destination for streaming data output. By default, this is a string stream, but it can be redirected to a file.
Fields
raw: SBStreamRef
The underlying raw SBStreamRef.
Methods
impl SBStream[src]
pub fn new() -> SBStream[src]
Construct a new SBStream.
pub fn wrap(raw: SBStreamRef) -> SBStream[src]
Construct a new SBStream.
pub fn maybe_wrap(raw: SBStreamRef) -> Option<SBStream>[src]
Construct a new Some(SBStream) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBStream value.
pub fn clear(&self)[src]
If the stream is directed to a file, forget about the file and if the ownership of the file was transferred to this object, close the file. If the stream is backed by a local cache, clear this cache.
pub fn data(&self) -> &str[src]
If this stream is not redirected to a file, this retrieves the locally cached data.
pub fn len(&self) -> usize[src]
If this stream is not redirected to a file, this retrieves the length of the locally cached data.
pub fn is_empty(&self) -> bool[src]
Is this stream empty?