Struct lldb::SBValue
[−]
[src]
pub struct SBValue {
pub raw: SBValueRef,
}The value of a variable, register or expression.
Fields
raw: SBValueRef
The underlying raw SBValueRef.
Methods
impl SBValue[src]
pub fn wrap(raw: SBValueRef) -> SBValue[src]
Construct a new SBValue.
pub fn maybe_wrap(raw: SBValueRef) -> Option<SBValue>[src]
Construct a new Some(SBValue) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBValue value.
pub fn clear(&self)[src]
pub fn error(&self) -> Option<SBError>[src]
pub fn id(&self) -> lldb_user_id_t[src]
pub fn name(&self) -> &str[src]
pub fn type_name(&self) -> &str[src]
pub fn display_type_name(&self) -> &str[src]
pub fn byte_size(&self) -> usize[src]
pub fn is_in_scope(&self) -> bool[src]
pub fn format(&self) -> Format[src]
pub fn set_format(&self, format: Format)[src]
pub fn value(&self) -> &str[src]
pub fn dereference(&self) -> Option<SBValue>[src]
pub fn address_of(&self) -> Option<SBValue>[src]
pub fn type_is_pointer_type(&self) -> bool[src]
pub fn target(&self) -> SBTarget[src]
pub fn process(&self) -> SBProcess[src]
pub fn thread(&self) -> SBThread[src]
pub fn frame(&self) -> SBFrame[src]
pub fn watch(
&self,
resolve_location: bool,
read: bool,
write: bool
) -> Result<SBWatchpoint, SBError>[src]
&self,
resolve_location: bool,
read: bool,
write: bool
) -> Result<SBWatchpoint, SBError>
Find and watch a variable.
pub fn watch_pointee(
&self,
resolve_location: bool,
read: bool,
write: bool
) -> Result<SBWatchpoint, SBError>[src]
&self,
resolve_location: bool,
read: bool,
write: bool
) -> Result<SBWatchpoint, SBError>
Find and watch the location pointed to by a variable.
pub fn pointee_data(&self, item_idx: u32, item_count: u32) -> Option<SBData>[src]
Get an SBData wrapping what this SBValue points to.
This method will dereference the current SBValue, if its
data type is a T* or T[], and extract item_count elements
of type T from it, copying their contents into an SBData.
item_idx is the index of the first item to retrieve. For an array
this is equivalent to array[item_idx], for a pointer
to *(pointer + item_idx). In either case, the measurement
unit for item_idx is the sizeof(T) rather than bytes.
item_count is how many items should be copied into the output.
By default only one item is copied, but more can be asked for.
Returns Some(SBData) with the contents of the copied items, on success.
None otherwise.
pub fn data(&self) -> Option<SBData>[src]
Get an SBData wrapping the contents of this SBValue.
This method will read the contents of this object in memory
and copy them into an SBData for future use.
Returns Some(SBData) with the contents of this SBValue, on success.
None otherwise.
pub fn set_data(&self, data: &SBData) -> Result<(), SBError>[src]
pub fn load_address(&self) -> Option<lldb_addr_t>[src]
pub fn address(&self) -> Option<SBAddress>[src]