Struct lldb::SBWatchpoint
[−]
[src]
pub struct SBWatchpoint {
pub raw: SBWatchpointRef,
}An instance of a watch point for a specific target program.
A watchpoint is determined by the address the byte size that resulted in this particular instantiation. Each watchpoint has its own settable options.
To Hit or Not
A watchpoint has multiple ways of controlling whether or not it should be considered active.
- Enabled. This is controlled via
is_enabledandset_enabled. - Ignore count. If set, this watchpoint will be ignored
the first ignore count times that it is hit. This is
controlled via
ignore_countandset_ignore_count.
A count of how many times a watchpoint has been it is
available via hit_count.
Fields
raw: SBWatchpointRef
The underlying raw SBWatchpointRef.
Methods
impl SBWatchpoint[src]
pub fn wrap(raw: SBWatchpointRef) -> SBWatchpoint[src]
Construct a new SBWatchpoint.
pub fn maybe_wrap(raw: SBWatchpointRef) -> Option<SBWatchpoint>[src]
Construct a new Some(SBWatchpoint) or None.
pub fn is_valid(&self) -> bool[src]
Check whether or not this is a valid SBWatchpoint value.
pub fn error(&self) -> Option<SBError>[src]
pub fn id(&self) -> i32[src]
pub fn hardware_index(&self) -> Option<i32>[src]
pub fn watch_address(&self) -> lldb_addr_t[src]
pub fn watch_size(&self) -> u32[src]
pub fn is_enabled(&self) -> bool[src]
pub fn set_enabled(&self, enabled: bool)[src]
pub fn hit_count(&self) -> u32[src]
pub fn ignore_count(&self) -> u32[src]
pub fn set_ignore_count(&self, count: u32)[src]