Struct lldb::SymbolContextItem [] [src]

#[repr(C)]
pub struct SymbolContextItem { /* fields omitted */ }

These mask bits allow a common interface for queries that can limit the amount of information that gets parsed to only the information that is requested. These bits also can indicate what actually did get resolved during query function calls.

Each definition corresponds to a one of the member variables in this class, and requests that that item be resolved, or indicates that the member did get resolved.

Methods

impl SymbolContextItem
[src]

TARGET: SymbolContextItem = SymbolContextItem{bits: 1,}

Set when a target is requested from a query or was located in the query results.

MODULE: SymbolContextItem = SymbolContextItem{bits: 2,}

Set when a module is requested from a query or was located in the query results.

COMPUNIT: SymbolContextItem = SymbolContextItem{bits: 4,}

Set when a compilation unit is requested from a query or was located in the query results.

FUNCTION: SymbolContextItem = SymbolContextItem{bits: 8,}

Set when a function is requested from a query or was located in the query results.

BLOCK: SymbolContextItem = SymbolContextItem{bits: 16,}

Set when the deepest block is requested from a query or was located in the query results.

LINE_ENTRY: SymbolContextItem = SymbolContextItem{bits: 32,}

Set when a line entry is requested from a query or was located in the query results.

SYMBOL: SymbolContextItem = SymbolContextItem{bits: 64,}

Set when a symbol is requested from a query or was located in the query results.

EVERYTHING: SymbolContextItem = SymbolContextItem{bits:
                      <Self>::TARGET.bits | <Self>::MODULE.bits |
                          <Self>::COMPUNIT.bits | <Self>::FUNCTION.bits |
                          <Self>::BLOCK.bits | <Self>::LINE_ENTRY.bits |
                          <Self>::SYMBOL.bits,}

Indicates to try and look everything up during a routine symbol context query. This doesn't actually include looking up a variable.

VARIABLE: SymbolContextItem = SymbolContextItem{bits: 128,}

Set when a global or static variable is requested from a query, or was located in the query results.

This is potentially expensive to look up, so it isn't included in EVERYTHING which stops it from being used during frame PC lookups and many other potential address to symbol context lookups.

[src]

Returns an empty set of flags.

[src]

Returns the set containing all flags.

[src]

Returns the raw value of the flags currently stored.

[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

[src]

Returns true if no flags are currently stored.

[src]

Returns true if all flags are currently set.

[src]

Returns true if there are flags common to both self and other.

[src]

Returns true all of the flags in other are contained within self.

[src]

Inserts the specified flags in-place.

[src]

Removes the specified flags in-place.

[src]

Toggles the specified flags in-place.

[src]

Inserts or removes the specified flags depending on the passed value.