Struct lldb::SymbolContextItem
[−]
[src]
#[repr(C)]pub struct SymbolContextItem { /* fields omitted */ }
These mask bits allow a common interface for queries that can limit the amount of information that gets parsed to only the information that is requested. These bits also can indicate what actually did get resolved during query function calls.
Each definition corresponds to a one of the member variables in this class, and requests that that item be resolved, or indicates that the member did get resolved.
Methods
impl SymbolContextItem[src]
pub const TARGET: SymbolContextItem
TARGET: SymbolContextItem = SymbolContextItem{bits: 1,}
Set when a target is requested from a query or was located in the query results.
pub const MODULE: SymbolContextItem
MODULE: SymbolContextItem = SymbolContextItem{bits: 2,}
Set when a module is requested from a query or was located in the query results.
pub const COMPUNIT: SymbolContextItem
COMPUNIT: SymbolContextItem = SymbolContextItem{bits: 4,}
Set when a compilation unit is requested from a query or was located in the query results.
pub const FUNCTION: SymbolContextItem
FUNCTION: SymbolContextItem = SymbolContextItem{bits: 8,}
Set when a function is requested from a query or was located in the query results.
pub const BLOCK: SymbolContextItem
BLOCK: SymbolContextItem = SymbolContextItem{bits: 16,}
Set when the deepest block is requested from a query or was located in the query results.
pub const LINE_ENTRY: SymbolContextItem
LINE_ENTRY: SymbolContextItem = SymbolContextItem{bits: 32,}
Set when a line entry is requested from a query or was located in the query results.
pub const SYMBOL: SymbolContextItem
SYMBOL: SymbolContextItem = SymbolContextItem{bits: 64,}
Set when a symbol is requested from a query or was located in the query results.
pub const EVERYTHING: SymbolContextItem
EVERYTHING: SymbolContextItem = SymbolContextItem{bits: <Self>::TARGET.bits | <Self>::MODULE.bits | <Self>::COMPUNIT.bits | <Self>::FUNCTION.bits | <Self>::BLOCK.bits | <Self>::LINE_ENTRY.bits | <Self>::SYMBOL.bits,}
Indicates to try and look everything up during a routine symbol context query. This doesn't actually include looking up a variable.
pub const VARIABLE: SymbolContextItem
VARIABLE: SymbolContextItem = SymbolContextItem{bits: 128,}
Set when a global or static variable is requested from a query, or was located in the query results.
This is potentially expensive to look up, so it isn't included in
EVERYTHING which stops it from being used during frame PC
lookups and many other potential address to symbol context lookups.
pub fn empty() -> SymbolContextItem[src]
Returns an empty set of flags.
pub fn all() -> SymbolContextItem[src]
Returns the set containing all flags.
pub fn bits(&self) -> u32[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<SymbolContextItem>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> SymbolContextItem[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub fn intersects(&self, other: SymbolContextItem) -> bool[src]
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: SymbolContextItem) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: SymbolContextItem)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: SymbolContextItem)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: SymbolContextItem)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: SymbolContextItem, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.